"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const snippetsApi_1 = require("../data/snippetsApi");
const pathUtils = require("path");
const TOKEN_KEY = "token";
exports.getToken = function (context, skipCache = false) {
    return __awaiter(this, void 0, void 0, function* () {
        let token = yield context.globalState.get(TOKEN_KEY);
        if (token && !skipCache) {
            return token;
        }
        token = yield vscode.window.showInputBox({
            placeHolder: "Please enter your Access Token...",
            prompt: "Find it at https://codesnippets.dev/token",
        });
        if (!token) {
            vscode.window.showErrorMessage("Well.... you're gonna need to enter an access token for this to work");
            return "";
        }
        yield context.globalState.update(TOKEN_KEY, token);
        return token;
    });
};
exports.insertCodeAtSelection = function (editor, code) {
    // Need to check for full VSCOde snippet format otherwise VScode has trouble with powershell variables $whatever
    let vsCodeSnippetRegex = /\${\d:.*}/gi;
    if (vsCodeSnippetRegex.test(code)) {
        // Escape all $ with a backslash to support having $ that isn't a VSCode Snippet placeholder
        // Then change the '\${' back to '${'
        code = code.replace(/\$/g, "\\$").replace(/\\\${/g, "${");
        let snippetString = new vscode.SnippetString(code);
        editor.insertSnippet(snippetString, editor.selection);
    }
    else {
        editor.edit((edit) => {
            edit.replace(editor.selection, code);
        });
    }
};
exports.chooseSnippets = function (token, language = "") {
    return __awaiter(this, void 0, void 0, function* () {
        let selected = (yield exports.selectSnippets(token, { language }));
        if (selected && selected.length) {
        }
        return [];
    });
};
const getManualSnippetPath = function () {
    return vscode.window.showInputBox({
        placeHolder: "Snippet path",
        prompt: "Ex: droopytersen/hooks/useDebounce.ts",
    });
};
exports.selectSnippets = (token, { language = "", canPickMany = false }) => __awaiter(this, void 0, void 0, function* () {
    let filter = {};
    if (language)
        filter.language = language;
    let snippets = yield snippetsApi_1.getSnippets(token, filter);
    let quickPickOptions = snippets.map((snippet) => (Object.assign({}, snippet, { label: snippet.title, detail: snippet.description + " " + snippet.tags.map((t) => t.key).join(", "), description: snippet.path })));
    quickPickOptions.unshift({
        key: "manual",
        label: "Other",
        description: "Choose to manually enter a Snippet path",
        detail: "Pull in any public snippet by entering the snippets path",
    });
    let selected = yield vscode.window.showQuickPick(quickPickOptions, {
        canPickMany,
        matchOnDescription: true,
        matchOnDetail: true,
        placeHolder: "Choose one of your snippets",
    });
    // if one of the choices was a manual path entry
    if (selected && Array.isArray(selected) && selected.find((s) => s.key === "manual")) {
        let target = selected.find((s) => s.key === "manual");
        target.path = yield getManualSnippetPath();
    }
    else if (selected && selected.key === "manual") {
        selected.path = yield getManualSnippetPath();
    }
    return selected;
});
exports.chooseSnippet = function (token, language = "") {
    return __awaiter(this, void 0, void 0, function* () {
        let selected = yield exports.selectSnippets(token, { language });
        if (selected.path) {
            return snippetsApi_1.getSnippet(token, selected.path);
        }
        return null;
    });
};
exports.getSelectedCode = function (editor) {
    if (!editor || !editor.selection)
        return "";
    const selection = editor.selection;
    let text = editor.document.getText(selection);
    return text;
};
exports.getLanguage = function (editor) {
    if (editor && editor.document) {
        return editor.document.languageId.replace("react", "");
    }
    return "text";
};
exports.getCurrentFileExtension = function (editor) {
    if (!editor || !editor.document || !editor.document.fileName)
        return "";
    let parsedPath = pathUtils.parse(editor.document.fileName);
    return parsedPath.ext;
};
//# sourceMappingURL=utils.js.map